@@ -480,10 +480,6 @@ proc ::safe::interpAddToAccessPath {slave path} {
 	if {[catch {::interp eval $slave\
 		{source [file join $tcl_library init.tcl]}}\
 		msg]} {
-	    if {![catch {::interp eval $slave\
-		    {source -rsrc init}} msg]} {
-		return $slave
-	    }
 	    Log $slave "can't source init.tcl ($msg)";
 	    error "can't source init.tcl into slave $slave ($msg)"
 	}
@@ -743,15 +739,9 @@ proc ::safe::setLogCmd {args} {
     proc AliasSource {slave args} {
 
 	set argc [llength $args];
-	# Allow only "source filename" and "source -rsrc filename"
-	if {($argc == 2) && ([lindex $args 0] == "-rsrc")} {
-	    if {[catch {::interp invokehidden $slave source -rsrc \
-		    [lindex $args 1]} msg]} {
-		Log $slave $msg;
-		return -code error "script error: $msg";
-	    }
-	    return $msg
-	}
+	# Allow only "source filename"
+	# (and not mac specific -rsrc for instance - see comment in ::init
+	# for current rationale)
 
 	if {$argc != 1} {
 	    set msg "wrong # args: should be \"source fileName\""
