@@ -344,18 +344,14 @@ CONST char *path;		/* Path to the executable in native
 }
 
 
-static char *startupLocale = NULL;
-static char *startupEncoding = NULL;
+static Tcl_Obj *startupLocale = NULL;
+static Tcl_Obj *startupEncoding = NULL;
 
 void
 TclpGetStartupLocaleEncoding(encodingPtr, localePtr)
-     char **encodingPtr;
-     char **localePtr;
+     Tcl_Obj **encodingPtr;
+     Tcl_Obj **localePtr;
 {
-    if (startupLocale == NULL ||
-	startupEncoding == NULL) {
-	Tcl_Panic("startup encoding is not set ??");
-    }
     if (encodingPtr != NULL) {
 	*encodingPtr = startupEncoding;
     }
@@ -370,25 +366,17 @@ SetStartupLocaleEncoding(encoding, locale)
      char *encoding;
      char *locale;
 {
-    static int inited = 0;
-    if (inited == 0) {
-	char *loc = locale;
-	unsigned int len;
-	inited = 1;
+    if (!startupLocale) {
 	if (encoding == NULL || encoding[0] == '\0') {
 	    Tcl_Panic("what's up?? can't get initial encoding??");
 	}
 	if (locale == NULL || locale[0] == '\0') {
-	    loc = "C";
+	    locale = "C";
 	}
-	len = strlen(encoding);
-	startupEncoding = (char *)ckalloc(sizeof(char) * (len + 1));
-	memcpy((VOID *)startupEncoding, (VOID *)encoding, len);
-	startupEncoding[len] = '\0';
-	len = strlen(loc);
-	startupLocale = (char *)ckalloc(sizeof(char) * (len + 1));
-	memcpy((VOID *)startupLocale, (VOID *)loc, len);
-	startupLocale[len] = '\0';
+	startupEncoding = Tcl_NewStringObj(encoding,-1);
+	Tcl_IncrRefCount(startupEncoding);
+	startupLocale = Tcl_NewStringObj(locale,-1);
+	Tcl_IncrRefCount(startupLocale);
     }
 }
 
@@ -482,6 +470,7 @@ TclpSetInitialEncodings()
     Tcl_SetSystemEncoding(NULL, encoding);
 
     SetStartupLocaleEncoding((char *)encoding, langEnv);
+
     /*
      * Hey, Belows are helpful for X11 XIM, NOT!!!!
      * If setlocale(LC_ALL, "") are once called, NOT reset to "C"
@@ -588,6 +577,8 @@ TclpSetVariables(interp)
     int unameOK;
     char *user;
     Tcl_DString ds;
+    Tcl_Obj *encoding;
+    Tcl_Obj *locale;
 
     Tcl_SetVar(interp, "tclDefaultLibrary", defaultLibraryDir, TCL_GLOBAL_ONLY);
     Tcl_SetVar(interp, "tcl_pkgPath", pkgPath, TCL_GLOBAL_ONLY);
@@ -645,9 +636,16 @@ TclpSetVariables(interp)
 	    user = "";
 	}
     }
-    Tcl_SetVar2(interp, "tcl_platform", "user", user, TCL_GLOBAL_ONLY);
     Tcl_DStringFree(&ds);
 
+    Tcl_SetVar2(interp, "tcl_platform", "user", user, TCL_GLOBAL_ONLY);
+    TclpGetStartupLocaleEncoding(&encoding, &locale);
+    if (encoding) {
+	Tcl_SetVar2Ex(interp, "tcl_platform", "encoding", encoding, TCL_GLOBAL_ONLY);
+    }
+    if (locale) {
+	Tcl_SetVar2Ex(interp, "tcl_platform", "locale", locale, TCL_GLOBAL_ONLY);
+    }
 }
 
 /*
